package main

import (
	"context"
	"encoding/xml"
	"fmt"
	"github.com/minio/minio-go/v7"
	"github.com/minio/minio-go/v7/pkg/credentials"
	"io/ioutil"
	"log"
	"os"
	"testing"
)

/*
minio:

	endpointPrivate: http://10.14.85.242:9000/
	endpointPublic: http://36.110.106.156:9000/
	access-key: minio_admin
	secret-key: 1qaz2wsx!
	bucket-name: simulation-cloud
*/
func TestConnectMinio(t *testing.T) {
	endpoint := "36.110.106.156:9000"
	accessKeyID := "minio_admin"
	secretAccessKey := "1qaz2wsx!"

	// Initialize minio client object.
	minioClient, err := minio.New(endpoint, &minio.Options{
		Creds:  credentials.NewStaticV4(accessKeyID, secretAccessKey, ""),
		Secure: false,
	})
	if err != nil {
		log.Fatalln(err)
	}

	log.Printf("%#v\n", minioClient) // minioClient is now set up

}

func TestDownloadFromMinio(t *testing.T) {
	endpoint := "36.110.106.156:9000"
	accessKeyID := "minio_admin"
	secretAccessKey := "1qaz2wsx!"

	// Initialize minio client object.
	minioClient, err := minio.New(endpoint, &minio.Options{
		Creds:  credentials.NewStaticV4(accessKeyID, secretAccessKey, ""),
		Secure: false,
	})
	if err != nil {
		log.Fatalln(err)
	}

	log.Printf("%#v\n", minioClient) // minioClient is now set up

	// 下载文件
	bucketName := "simulation-cloud"
	objectName := "road_model/Osgb/China_Crossing_002.opt.osgb"
	filePath := "D:\\China_Crossing_002.opt.osgb"

	err = minioClient.FGetObject(context.Background(), bucketName, objectName, filePath, minio.GetObjectOptions{})
	if err != nil {
		log.Fatalln(err)
	}
	fmt.Printf("Successfully downloaded %s to %s\n", objectName, filePath)
}

func TestGetBegin(t *testing.T) {
	file, err := os.Open("D:\\test.xosc")
	if err != nil {
		fmt.Println("Error opening file:", err)
		return
	}
	defer file.Close()

	data, err := ioutil.ReadAll(file)
	if err != nil {
		fmt.Println("Error reading file:", err)
		return
	}

	var result interface{}
	err = xml.Unmarshal(data, &result)
	if err != nil {
		fmt.Println("Error unmarshaling XML:", err)
		return
	}
}
